@@ -40,7 +40,6 @@ enum {
   PROP_SHOW_MODE_SELECTION,
   PROP_VALID,
   PROP_BLANK_MODE,
-  PROP_ACCEPT_ONLY_CD,
 };
 
 enum {
@@ -84,7 +83,6 @@ typedef struct
   GtkWidget *combo_mode;
 
   gboolean have_asked_for_blanking;
-  gboolean accept_only_cd;
 
   gulong handler_volume_change_start;
   gulong handler_volume_change_end;
@@ -187,10 +185,6 @@ xfburn_device_box_class_init (XfburnDeviceBoxClass * klass)
                                    g_param_spec_boolean ("blank-mode", _("Blank mode"),
                                                         _("The blank mode shows different disc status messages than regular mode"), 
                                                         FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-  g_object_class_install_property (object_class, PROP_ACCEPT_ONLY_CD, 
-                                   g_param_spec_boolean ("accept-only-cd", _("Accept only CDs as valid discs"),
-                                                        _("Accept only CDs as valid discs"), 
-                                                        FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
 static GObject * 
@@ -333,9 +327,6 @@ xfburn_device_box_get_property (GObject *object, guint prop_id, GValue *value, G
     case PROP_BLANK_MODE:
       g_value_set_boolean (value, priv->blank_mode);
       break;
-    case PROP_ACCEPT_ONLY_CD:
-      g_value_set_boolean (value, priv->accept_only_cd);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -360,9 +351,6 @@ xfburn_device_box_set_property (GObject *object, guint prop_id, const GValue *va
     case PROP_BLANK_MODE:
       priv->blank_mode = g_value_get_boolean (value);
       break;
-    case PROP_ACCEPT_ONLY_CD:
-      priv->accept_only_cd = g_value_get_boolean (value);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -428,15 +416,17 @@ fill_combo_speed (XfburnDeviceBox *box, XfburnDevice *device)
 {
   XfburnDeviceBoxPrivate *priv = XFBURN_DEVICE_BOX_GET_PRIVATE (box);
   GtkTreeModel *model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->combo_speed));
-  GSList *el;
-  int profile_no;
+  GSList *el = NULL;
+  int profile_no = 0;
   int factor;
   GtkTreeIter iter_max;
 
-  g_object_get (G_OBJECT (xfburn_device_list_get_current_device (priv->devlist)),
-                "profile-no", &profile_no,
-                "supported-speeds", &el,
-                NULL);
+  if (device) {
+    g_object_get (G_OBJECT (device),
+                  "profile-no", &profile_no,
+                  "supported-speeds", &el,
+                  NULL);
+  }
 
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
@@ -456,12 +446,7 @@ fill_combo_speed (XfburnDeviceBox *box, XfburnDevice *device)
 
   /* check profile, so we can convert from 'kb/s' into 'x' rating */
   if (profile_no != 0) {
-    /* this will fail if newer disk types get supported */
-    if (profile_no <= 0x0a)
-      factor = CDR_1X_SPEED;
-    else
-      /* assume DVD for now */
-      factor = DVD_1X_SPEED;
+    factor = xfburn_media_profile_to_kb (profile_no);
   } else {
     factor = 1;
   }
@@ -535,20 +520,24 @@ ask_for_blanking (XfburnDeviceBoxPrivate *priv)
 static gboolean
 check_disc_validity (XfburnDeviceBoxPrivate *priv)
 {
-  enum burn_disc_status disc_status;
-  int profile_no;
-  gchar *profile_name;
-  gboolean is_erasable;
-  XfburnDevice *device;
+  enum burn_disc_status disc_status = BURN_DISC_UNREADY;
+  int profile_no = 0;
+  gchar *profile_name = NULL;
+  gboolean is_erasable = FALSE;
+  XfburnDevice *device = NULL;
 
   g_object_get (G_OBJECT (priv->devlist), "current-device", &device, NULL);
 
+  if (device == NULL)
+    return FALSE;
+
   g_object_get (G_OBJECT (device), "disc-status", &disc_status, "profile-no", &profile_no, 
                                    "erasable", &is_erasable, "profile-name", &profile_name,
                                    NULL);
-  
-  gtk_label_set_text (GTK_LABEL (priv->disc_label), profile_name);
-  g_free (profile_name);
+  if (profile_name != NULL) {
+    gtk_label_set_text (GTK_LABEL (priv->disc_label), profile_name);
+    g_free (profile_name);
+  }
 
   DBG ("blank_mode = %d", priv->blank_mode);
 
@@ -556,20 +545,13 @@ check_disc_validity (XfburnDeviceBoxPrivate *priv)
     /* for burning */
     switch (profile_no) {
       case XFBURN_PROFILE_NONE:
-        /* empty drive is caught later,
-         * not sure if there would be another reason for 0x0 */
-        priv->valid_disc = TRUE;
-        break;
+        /* Very old CD burner (MMC-1) or unsuitable medium.
+         * An unsuitable medium will later be marked invalid because it is not
+         * BURN_DISC_BLANK. So for now it is a valid disc on probation.
+         */
       case XFBURN_PROFILE_CDR:
-        g_object_get (G_OBJECT (device), "cdr", &priv->valid_disc, NULL);
-        break;
       case XFBURN_PROFILE_CDRW:
-        g_object_get (G_OBJECT (device), "cdrw", &priv->valid_disc, NULL);
-        break;
       case XFBURN_PROFILE_DVDRAM:
-        if (!priv->accept_only_cd)
-          g_object_get (G_OBJECT (device), "dvdram", &priv->valid_disc, NULL);
-        break;
       case XFBURN_PROFILE_DVD_MINUS_R:
       case XFBURN_PROFILE_DVD_MINUS_RW_OVERWRITE:
       case XFBURN_PROFILE_DVD_MINUS_RW_SEQUENTIAL:
@@ -577,8 +559,15 @@ check_disc_validity (XfburnDeviceBoxPrivate *priv)
       case XFBURN_PROFILE_DVD_PLUS_R:
       case XFBURN_PROFILE_DVD_PLUS_R_DL:
       case XFBURN_PROFILE_DVD_PLUS_RW:
-        if (!priv->accept_only_cd)
-          g_object_get (G_OBJECT (device), "dvdr", &priv->valid_disc, NULL);
+      case XFBURN_PROFILE_BD_R:
+      case XFBURN_PROFILE_BD_RE:
+        priv->valid_disc = TRUE;
+        break;
+      case XFBURN_PROFILE_CDROM:
+      case XFBURN_PROFILE_DVDROM:
+      case XFBURN_PROFILE_BDROM:
+        g_warning ("Read-only profile 0x%x!", profile_no);
+        priv->valid_disc = FALSE;
         break;
       default:
         g_warning ("Unknown disc profile 0x%x!", profile_no);
@@ -676,20 +665,23 @@ fill_combo_mode (XfburnDeviceBox *box, XfburnDevice *device)
   XfburnDeviceBoxPrivate *priv = XFBURN_DEVICE_BOX_GET_PRIVATE (box);
   GtkTreeModel *model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->combo_mode));
   GtkTreeIter iter;
-  gint block_types;
+  gint block_types = 0;
 
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
   gtk_list_store_append (GTK_LIST_STORE (model), &iter);
   gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, _("Auto"), MODE_VALUE_COLUMN, WRITE_MODE_AUTO, -1);
 
-  g_object_get (G_OBJECT (device), "tao-block-types", &block_types, NULL);
+  if (device) 
+    g_object_get (G_OBJECT (device), "tao-block-types", &block_types, NULL);
+
   if (block_types) {
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, "TAO", MODE_VALUE_COLUMN, WRITE_MODE_TAO, -1);
   }
 
-  g_object_get (G_OBJECT (device), "sao-block-types", &block_types, NULL);
+  if (device) 
+    g_object_get (G_OBJECT (device), "sao-block-types", &block_types, NULL);
   if (block_types & BURN_BLOCK_SAO) {
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter, MODE_TEXT_COLUMN, "SAO", MODE_VALUE_COLUMN, WRITE_MODE_SAO, -1);
@@ -785,7 +777,6 @@ xfburn_device_box_new (XfburnDeviceBoxFlags flags)
                       "show-speed-selection", ((flags & SHOW_SPEED_SELECTION) != 0), 
 		      "show-mode-selection", ((flags & SHOW_MODE_SELECTION) != 0),
 		      "blank-mode", ((flags & BLANK_MODE) != 0),
-		      "accept-only-cd", ((flags & ACCEPT_ONLY_CD) != 0),
                       NULL);
   
   return obj;
