@@ -1,4 +1,3 @@
-/* $Id: xfburn-transcoder-basic.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *  Copyright (c) 2008      David Mohr (dmohr@mcbf.net)
@@ -34,7 +33,7 @@
 #include <errno.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <libburn.h>
 
@@ -84,7 +83,7 @@ static GObject *parent_class = NULL;
 //static guint signals[LAST_SIGNAL];
 
 GType
-xfburn_transcoder_basic_get_type ()
+xfburn_transcoder_basic_get_type (void)
 {
   static GType type = 0;
 
@@ -236,7 +235,7 @@ is_valid_wav (const gchar *path)
   fd = open (path, 0);
 
   if (fd == -1) {
-    xfce_warn (_("Could not open %s."), path);
+    xfce_dialog_show_warning(NULL, "", _("Could not open %s."), path);
     return FALSE;
   }
 
@@ -367,7 +366,7 @@ needs_swap (char header[44])
 /*        */
 
 GObject *
-xfburn_transcoder_basic_new ()
+xfburn_transcoder_basic_new (void)
 {
   return g_object_new (XFBURN_TYPE_TRANSCODER_BASIC, NULL);
 }
