@@ -89,7 +89,7 @@ static gboolean query_and_signal_duration (XfburnTranscoderGst *trans);
 
 /* gstreamer support functions */
 static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data);
-static void on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data);
+static void on_pad_added (GstElement *element, GstPad *pad, gpointer data);
 
 #ifdef DEBUG_GST
 static void cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data);
@@ -110,7 +110,7 @@ typedef enum {
 
 typedef struct {
   GstElement *pipeline;
-  GstElement *source, *decoder, *resample, *conv, *sink;
+  GstElement *source, *decoder, *resample, *conv1, *conv2, *sink;
 
   XfburnTranscoderGstState state;
   GCond gst_cond;
@@ -257,7 +257,7 @@ create_pipeline (XfburnTranscoderGst *trans)
 {
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (trans);
 
-  GstElement *pipeline, *source, *decoder, *resample, *conv, *sink;
+  GstElement *pipeline, *source, *decoder, *resample, *conv1, *conv2, *sink;
 #if DEBUG_GST > 0 && DEBUG > 0
   GstElement *id;
 #endif
@@ -268,18 +268,18 @@ create_pipeline (XfburnTranscoderGst *trans)
 
   priv->pipeline = pipeline = gst_pipeline_new ("transcoder");
 
-  priv->source  = source   = gst_element_factory_make ("filesrc",       "file-source");
-  priv->decoder = decoder  = gst_element_factory_make ("decodebin",     "decoder");
-  priv->resample= resample = gst_element_factory_make ("audioresample", "resampler");
-  priv->conv    = conv     = gst_element_factory_make ("audioconvert",  "converter");
+  priv->source   = source   = gst_element_factory_make ("filesrc",       "file-source");
+  priv->decoder  = decoder  = gst_element_factory_make ("decodebin",     "decoder");
+  priv->conv1    = conv1    = gst_element_factory_make ("audioconvert",  "converter1");
+  priv->resample = resample = gst_element_factory_make ("audioresample", "resampler");
+  priv->conv2    = conv2    = gst_element_factory_make ("audioconvert",  "converter2");
 #if DEBUG_GST > 0 && DEBUG > 0
                   id       = gst_element_factory_make ("identity",      "debugging-identity");
 #endif
   priv->sink    = sink     = gst_element_factory_make ("fdsink",        "audio-output");
   //priv->sink    = sink     = gst_element_factory_make ("fakesink",        "audio-output");
-  //DBG ("\npipeline = %p\nsource = %p\ndecoder = %p\nconv = %p\nsink = %p", pipeline, source, decoder, conv, sink);
 
-  if (!pipeline || !source || !decoder || !resample || !conv || !sink) {
+  if (!pipeline || !source || !decoder || !resample || !conv1 || !conv2 || !sink) {
     g_warning ("A pipeline element could not be created");
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_CREATION,
 		    "%s",
@@ -304,28 +304,27 @@ create_pipeline (XfburnTranscoderGst *trans)
   gst_object_unref (bus);
 
   gst_bin_add_many (GST_BIN (pipeline),
-                    source, decoder, resample, conv, sink, NULL);
+                    source, decoder, conv1, resample, conv2, sink, NULL);
 #if DEBUG_GST > 0 && DEBUG > 0
   gst_bin_add (GST_BIN (pipeline), id);
 #endif
 
   gst_element_link (source, decoder);
-  gst_element_link (resample, conv);
+  gst_element_link (conv1, resample);
+  gst_element_link (resample, conv2);
 
   /* setup caps for raw pcm data */
-  caps = gst_caps_new_simple ("audio/x-raw-int",
+  caps = gst_caps_new_simple ("audio/x-raw",
             "rate", G_TYPE_INT, 44100,
             "channels", G_TYPE_INT, 2,
-            "endianness", G_TYPE_INT, G_LITTLE_ENDIAN,
-            "width", G_TYPE_INT, 16,
-            "depth", G_TYPE_INT, 16,
-            "signed", G_TYPE_BOOLEAN, TRUE,
+            "format", G_TYPE_STRING, "S16LE",
             NULL);
 
 #if DEBUG_GST > 0 && DEBUG > 0
-  if (!gst_element_link_filtered (conv, id, caps)) {
+  // TODO without the filter it does work but I'm not sure the audio format is correct
+  if (!gst_element_link_filtered (conv2, id, caps)) {
 #else
-  if (!gst_element_link_filtered (conv, sink, caps)) {
+  if (!gst_element_link_filtered (conv2, sink, caps)) {
 #endif
     g_warning ("Could not setup filtered gstreamer link");
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_CREATION,
@@ -340,7 +339,7 @@ create_pipeline (XfburnTranscoderGst *trans)
   g_signal_connect (id, "handoff", G_CALLBACK (cb_handoff), id);
 #endif
 
-  g_signal_connect (decoder, "new-decoded-pad", G_CALLBACK (on_pad_added), trans);
+  g_signal_connect (decoder, "pad-added", G_CALLBACK (on_pad_added), trans);
 }
 
 static void 
@@ -446,7 +445,7 @@ query_and_signal_duration (XfburnTranscoderGst *trans)
   //guint secs;
 
   fmt = GST_FORMAT_TIME;
-  if (!gst_element_query_duration (priv->pipeline, &fmt, &priv->duration)) {
+  if (!gst_element_query_duration (priv->pipeline, fmt, &priv->duration)) {
     return FALSE;
   }
 
@@ -604,7 +603,7 @@ bus_call (GstBus *bus, GstMessage *msg, gpointer data)
       break;
     }
 
-    case GST_MESSAGE_DURATION: {
+    case GST_MESSAGE_DURATION_CHANGED: {
 
       switch (priv->state) {
         case XFBURN_TRANSCODER_GST_STATE_IDLE:
@@ -653,7 +652,7 @@ bus_call (GstBus *bus, GstMessage *msg, gpointer data)
 }
 
 static void
-on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
+on_pad_added (GstElement *element, GstPad *pad, gpointer data)
 {
   XfburnTranscoderGst *trans = XFBURN_TRANSCODER_GST (data);
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (trans);
@@ -661,7 +660,7 @@ on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
   GstCaps *caps;
   GstStructure *str;
   GstPad *audiopad;
-  GstElement *audio = (GstElement *) priv->resample;
+  GstElement *audio = (GstElement *) priv->conv1;
 
   // only link once
   audiopad = gst_element_get_static_pad (audio, "sink");
@@ -676,7 +675,7 @@ on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
 #endif
 
   // check disc type
-  caps = gst_pad_get_caps (pad);
+  caps = gst_pad_query_caps (pad, NULL);
   str = gst_caps_get_structure (caps, 0);
   if (!g_strrstr (gst_structure_get_name (str), "audio")) {
     GstStructure *msg_struct;
@@ -695,7 +694,7 @@ on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
 		    "%s",
                  _(error_msg));
     
-    msg_struct = gst_structure_new ("no-audio-content", NULL);
+    msg_struct = gst_structure_new_empty ("no-audio-content");
 
     msg = gst_message_new_application (GST_OBJECT (element), msg_struct);
 
@@ -744,7 +743,7 @@ get_description (XfburnTranscoder *trans)
 static void
 cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data)
 {
-  guint size = GST_BUFFER_SIZE (buffer);
+  guint size = gst_buffer_get_size (buffer);
 #if DEBUG_GST > 2
   static int i = 0;
   const int step = 30;
